@@ -47,6 +47,7 @@ as follows:
     get_thumb_height
     get_thumb_width
     get_keywords
+    get_guid
 
 =cut
 
@@ -183,11 +184,11 @@ sub get_hashref {
 
 =head1 Copyright
 
-Copyright (C) 2006 Lokku Ltd.
+Copyright (C) 2008 Lokku Ltd.
 
 =head1 Author
 
-Alex Balhatchet (kaoru@slackwise.net)
+Alex Balhatchet (kaoru at slackwise dot net), Yoav Felberbaum (perl at mrdini dot com)
 
 =cut
 
